==> chewing-editor_0.0.4.orig.tar.gz: chewing-editor-0.0.4/ts/chewing-editor_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>ChewingEditor</name>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="20"/>
        <source>Chewing user phrase editor</source>
        <translation>新酷音詞庫編輯器</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="vanished">過濾</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="75"/>
        <source>File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="vanished">編輯</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="27"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="34"/>
        <source>Remove</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="48"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="84"/>
        <source>Help</source>
        <translation>求助</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="94"/>
        <source>&amp;Import</source>
        <translation>匯入(&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="99"/>
        <source>&amp;Export</source>
        <translation>匯出(&amp;E)</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="114"/>
        <source>E&amp;xit</source>
        <translation>離開(&amp;X)</translation>
    </message>
    <message>
        <source>Add phrase</source>
        <translation type="vanished">新增詞彙</translation>
    </message>
    <message>
        <source>Remove phrase</source>
        <translation type="vanished">刪除詞彙</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="41"/>
        <source>Refresh</source>
        <translation>更新</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="104"/>
        <source>About Chewing editor</source>
        <translation>關於新酷音詞庫編輯器</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="109"/>
        <source>About Qt</source>
        <translation>關於 Qt</translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="69"/>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="77"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
</context>
<context>
    <name>Notification</name>
    <message>
        <location filename="../src/view/Notification.cpp" line="39"/>
        <source>%1 %2 %3</source>
        <translation></translation>
    </message>
    <message>
        <source>Import %1 successful.</source>
        <translation type="vanished">成功匯入 &quot;%1&quot; 。</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="41"/>
        <source>%n phrase(s) are imported.</source>
        <translation>
            <numerusform>匯入 %n 個詞彙。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="42"/>
        <source>Total %n user phrase(s).</source>
        <translation>
            <numerusform>目前共有 %n 個詞彙。</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="57"/>
        <source>%1 %2</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="59"/>
        <source>%n phrase(s) are exported.</source>
        <translation>
            <numerusform>有 %n 個詞彙被匯出。</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="40"/>
        <source>Import &quot;%1&quot; successful.</source>
        <translation>成功匯入 &quot;%1&quot; 。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="44"/>
        <source>Import &quot;%1&quot; failed.</source>
        <translation>無法匯入 &quot;%1&quot;。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="58"/>
        <source>Export &quot;%1&quot; successful.</source>
        <translation>成功匯出 &quot;%1&quot; 。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="61"/>
        <source>Export &quot;%1&quot; failed.</source>
        <translation>匯出 &quot;%1&quot; 失敗。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="69"/>
        <source>Add new phrase %1 successful.</source>
        <translation>成功新增 「%1」。</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="77"/>
        <source>Remove %n phrase(s) successful.</source>
        <translation>
            <numerusform>成功移除 %n 個詞彙。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="84"/>
        <source>Refresh completed. Total %n user phrase(s).</source>
        <translation>
            <numerusform>更新完成。共有 %n 個詞彙。</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UserphraseDialog</name>
    <message>
        <source>Add new user phrase</source>
        <translation type="vanished">新增詞彙</translation>
    </message>
    <message>
        <source>phrase</source>
        <translation type="vanished">詞彙</translation>
    </message>
    <message>
        <source>bopomofo</source>
        <translation type="vanished">注音</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="14"/>
        <source>Add new phrase</source>
        <translation>新增詞彙</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="25"/>
        <source>Phrase:</source>
        <translation>詞彙:</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="35"/>
        <source>Bopomofo:</source>
        <translation>注音:</translation>
    </message>
</context>
<context>
    <name>UserphraseView</name>
    <message>
        <location filename="../src/view/UserphraseView.cpp" line="43"/>
        <source>Add new phrase</source>
        <translation>新增詞彙</translation>
    </message>
    <message>
        <location filename="../src/view/UserphraseView.cpp" line="58"/>
        <source>Modify phrase</source>
        <translation>修改詞彙</translation>
    </message>
</context>
<context>
    <name>UserphraseViewMenu</name>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="7"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="12"/>
        <source>Modify</source>
        <translation>修改</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="17"/>
        <source>Remove</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>%1
</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="105"/>
        <source>chewing-editor is a cross platform chewing user phrase editor written in Qt5. It provides a user friendly GUI to manage user phrase. With it, user can customize user phrase to enhance chewing input performance.</source>
        <translation>新酷音詞庫編輯器是一個使用 Qt5 撰寫的跨平台新酷音詞彙編輯器。他提供了友善的圖形化使用者界面讓使用者管理詞彙，讓使用者可以自行客製化詞庫以提昇新酷音輸入法的表現。</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="113"/>
        <source>-d, --debug</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="114"/>
        <source>Enable debug message.</source>
        <translation>啟用偵錯資訊</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>-v, --version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="118"/>
        <source>Print program version.</source>
        <translation>顯示程式版本資訊</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="121"/>
        <source>-h, --help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="122"/>
        <source>Print help message.</source>
        <translation>顯示說明訊息</translation>
    </message>
</context>
</TS>

==> chewing-editor_0.1.2.orig.tar.gz: chewing-editor-0.1.2/ts/chewing-editor_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>ChewingEditor</name>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="20"/>
        <source>Chewing user phrase editor</source>
        <translation>新酷音詞庫編輯器</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="vanished">過濾</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="82"/>
        <source>File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="vanished">編輯</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="27"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="34"/>
        <source>Remove</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="55"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="91"/>
        <source>Help</source>
        <translation>求助</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="101"/>
        <source>&amp;Import</source>
        <translation>匯入(&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="106"/>
        <source>&amp;Export</source>
        <translation>匯出(&amp;E)</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="127"/>
        <source>E&amp;xit</source>
        <translation>離開(&amp;X)</translation>
    </message>
    <message>
        <source>Add phrase</source>
        <translation type="vanished">新增詞彙</translation>
    </message>
    <message>
        <source>Remove phrase</source>
        <translation type="vanished">刪除詞彙</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="48"/>
        <source>Refresh</source>
        <translation>更新</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="41"/>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="111"/>
        <source>About Chewing editor</source>
        <translation>關於新酷音詞庫編輯器</translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="119"/>
        <source>About Qt</source>
        <translation>關於 Qt</translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="69"/>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="77"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="196"/>
        <source>Do you want to delete this phrase?</source>
        <translation>你想要刪除這個詞彙嗎？</translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="199"/>
        <source>Delete phrase</source>
        <translation>刪除詞彙</translation>
    </message>
</context>
<context>
    <name>Notification</name>
    <message>
        <location filename="../src/view/Notification.cpp" line="39"/>
        <source>%1 %2 %3</source>
        <translation></translation>
    </message>
    <message>
        <source>Import %1 successful.</source>
        <translation type="vanished">成功匯入 &quot;%1&quot; 。</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="41"/>
        <source>%n phrase(s) are imported.</source>
        <translation>
            <numerusform>匯入 %n 個詞彙。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="42"/>
        <source>Total %n user phrase(s).</source>
        <translation>
            <numerusform>目前共有 %n 個詞彙。</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="57"/>
        <source>%1 %2</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="59"/>
        <source>%n phrase(s) are exported.</source>
        <translation>
            <numerusform>有 %n 個詞彙被匯出。</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="40"/>
        <source>Import &quot;%1&quot; successful.</source>
        <translation>成功匯入 &quot;%1&quot; 。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="44"/>
        <source>Import &quot;%1&quot; failed.</source>
        <translation>無法匯入 &quot;%1&quot;。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="58"/>
        <source>Export &quot;%1&quot; successful.</source>
        <translation>成功匯出 &quot;%1&quot; 。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="61"/>
        <source>Export &quot;%1&quot; failed.</source>
        <translation>匯出 &quot;%1&quot; 失敗。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="69"/>
        <source>Add new phrase %1 successful.</source>
        <translation>成功新增 「%1」。</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="77"/>
        <source>Remove %n phrase(s) successful.</source>
        <translation>
            <numerusform>成功移除 %n 個詞彙。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="84"/>
        <source>Refresh completed. Total %n user phrase(s).</source>
        <translation>
            <numerusform>更新完成。共有 %n 個詞彙。</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="89"/>
        <source>Add new phrase failed. Please enter the bopomofo for each word and try again.</source>
        <translation>新增詞彙失敗。請輸入每個字的注音後再試一次。</translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="94"/>
        <source>Undo completed. Revert %1.</source>
        <translation>復原完成。復原 「%1」。</translation>
    </message>
</context>
<context>
    <name>UserphraseDialog</name>
    <message>
        <source>Add new user phrase</source>
        <translation type="vanished">新增詞彙</translation>
    </message>
    <message>
        <source>phrase</source>
        <translation type="vanished">詞彙</translation>
    </message>
    <message>
        <source>bopomofo</source>
        <translation type="vanished">注音</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="14"/>
        <source>Add new phrase</source>
        <translation>新增詞彙</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="25"/>
        <source>Phrase:</source>
        <translation>詞彙:</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="35"/>
        <source>Bopomofo:</source>
        <translation>注音:</translation>
    </message>
</context>
<context>
    <name>UserphraseView</name>
    <message>
        <location filename="../src/view/UserphraseView.cpp" line="43"/>
        <source>Add new phrase</source>
        <translation>新增詞彙</translation>
    </message>
    <message>
        <location filename="../src/view/UserphraseView.cpp" line="58"/>
        <source>Modify phrase</source>
        <translation>修改詞彙</translation>
    </message>
</context>
<context>
    <name>UserphraseViewMenu</name>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="7"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="12"/>
        <source>Modify</source>
        <translation>修改</translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="17"/>
        <source>Remove</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>%1
</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="105"/>
        <source>chewing-editor is a cross platform chewing user phrase editor written in Qt5. It provides a user friendly GUI to manage user phrase. With it, user can customize user phrase to enhance chewing input performance.</source>
        <translation>新酷音詞庫編輯器是一個使用 Qt5 撰寫的跨平台新酷音詞彙編輯器。他提供了友善的圖形化使用者界面讓使用者管理詞彙，讓使用者可以自行客製化詞庫以提昇新酷音輸入法的表現。</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="113"/>
        <source>-d, --debug</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="114"/>
        <source>Enable debug message.</source>
        <translation>啟用偵錯資訊</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>-v, --version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="118"/>
        <source>Print program version.</source>
        <translation>顯示程式版本資訊</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="121"/>
        <source>-h, --help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="122"/>
        <source>Print help message.</source>
        <translation>顯示說明訊息</translation>
    </message>
</context>
</TS>
